#ifndef PING_H
#define PING_H

#include <string>
#include <qglobal.h>

#if !defined(_WIN32)
using namespace std;
#endif

class Ping
{
 public:
  Ping(const Q_UINT8 ttl, const Q_UINT8 hops, std::string id);

  std::string  _id;
  std::string  _data;
  Q_UINT8      _ttl;
  Q_UINT8      _hops;
};

#endif
